Scora Notify
=============================
This package implements Slack notification and Mixpanel abstractions to be used in various projects.

This packages uses logging for console outputs.

The Slack notifier can:
* Start threads
* Update threads
* Finish threads

The event tracker can:
* Track events
* Time events 

To time an event, call the time_event method with the desired event_name, and later call track on that same event. The duration between calls will be saved as the "Duration" property.

Development
-----------------------------


Build, install, test locally
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. code-block:: bash

    # build from this source -- considering that dependencies are resolved
    rm -rf ./dist/* && python3 -m build

    # From another venv -- install 
    virtualenv -p python3
    . ./venv/bin/activate
    pip install <REPO_HOME>/dist/scora-notify-0.1.0.tar.gz 


    # Import and run
    from scora_notify import Notify 
    notify=Notify(slack_token="", slack_channel="", step="", tenant="", project="")

    # Import and run
    from scora_notify import EventTracker 
    tracker = src.EventTracker("",project="",tenant="")
    tracker.track("event",properties={"prop":1})

